aboutsummaryrefslogtreecommitdiff
path: root/gdb/gdbtypes.h
diff options
context:
space:
mode:
authorJan Kratochvil <jan.kratochvil@redhat.com>2017-02-20 20:53:21 +0100
committerJan Kratochvil <jan.kratochvil@redhat.com>2017-02-20 21:00:55 +0100
commit216f72a1ed20a8c9cdaea74e03be24601a1ed974 (patch)
tree1904283f1a601d402aeeab7563dafd8b1cb9a072 /gdb/gdbtypes.h
parent43988095a5a4c53e6d5b00a6335454919c4fac55 (diff)
DWARF-5: call sites
this patch updates all call sites related DWARF-5 renames. gdb/ChangeLog 2017-02-20 Jan Kratochvil <jan.kratochvil@redhat.com> * block.c (call_site_for_pc): Rename DW_OP_GNU_*, DW_TAG_GNU_* and DW_AT_GNU_*. * common/common-exceptions.h (enum errors): Likewise. * dwarf2-frame.c (class dwarf_expr_executor): Likewise. * dwarf2expr.c (dwarf_block_to_dwarf_reg) (dwarf_expr_context::execute_stack_op): Likewise. * dwarf2expr.h (struct dwarf_expr_context, struct dwarf_expr_piece): Likewise. * dwarf2loc.c (dwarf_evaluate_loc_desc::get_base_type) (dwarf_evaluate_loc_desc::push_dwarf_reg_entry_value) (show_entry_values_debug, call_site_to_target_addr) (func_addr_to_tail_call_list, func_verify_no_selftailcall) (dwarf_expr_reg_to_entry_parameter, dwarf_entry_parameter_to_value) (entry_data_value_free_closure, value_of_dwarf_reg_entry) (value_of_dwarf_block_entry, indirect_pieced_value) (symbol_needs_eval_context::push_dwarf_reg_entry_value): (disassemble_dwarf_expression): Likewise. * dwarf2read.c (process_die, inherit_abstract_dies) (read_call_site_scope): Likewise. * gdbtypes.h (struct func_type, struct call_site_parameter) (struct call_site): Likewise. * stack.c (read_frame_arg): Likewise. * std-operator.def (OP_VAR_ENTRY_VALUE): Likewise. gdb/doc/ChangeLog 2017-02-20 Jan Kratochvil <jan.kratochvil@redhat.com> * gdb.texinfo (Print Settings, Tail Call Frames): Rename DW_OP_GNU_*, DW_TAG_GNU_* and DW_AT_GNU_*. gdb/testsuite/ChangeLog 2017-02-20 Jan Kratochvil <jan.kratochvil@redhat.com> * gdb.arch/amd64-entry-value-param-dwarf5.S: New file. * gdb.arch/amd64-entry-value-param-dwarf5.c: New file. * gdb.arch/amd64-entry-value-param-dwarf5.exp: New file. * gdb.arch/amd64-entry-value.exp: Rename DW_OP_GNU_*, DW_TAG_GNU_* and DW_AT_GNU_*.
Diffstat (limited to 'gdb/gdbtypes.h')
-rw-r--r--gdb/gdbtypes.h22
1 files changed, 10 insertions, 12 deletions
diff --git a/gdb/gdbtypes.h b/gdb/gdbtypes.h
index 5852160de4..e094ecef3a 100644
--- a/gdb/gdbtypes.h
+++ b/gdb/gdbtypes.h
@@ -1041,12 +1041,12 @@ struct func_type
unsigned int is_noreturn : 1;
- /* * Only those DW_TAG_GNU_call_site's in this function that have
- DW_AT_GNU_tail_call set are linked in this list. Function
+ /* * Only those DW_TAG_call_site's in this function that have
+ DW_AT_call_tail_call set are linked in this list. Function
without its tail call list complete
- (DW_AT_GNU_all_tail_call_sites or its superset
- DW_AT_GNU_all_call_sites) has TAIL_CALL_LIST NULL, even if some
- DW_TAG_GNU_call_site's exist in such function. */
+ (DW_AT_call_all_tail_calls or its superset
+ DW_AT_call_all_calls) has TAIL_CALL_LIST NULL, even if some
+ DW_TAG_call_site's exist in such function. */
struct call_site *tail_call_list;
@@ -1106,13 +1106,12 @@ struct call_site_parameter
union call_site_parameter_u u;
- /* * DW_TAG_formal_parameter's DW_AT_GNU_call_site_value. It
- is never NULL. */
+ /* * DW_TAG_formal_parameter's DW_AT_call_value. It is never NULL. */
const gdb_byte *value;
size_t value_size;
- /* * DW_TAG_formal_parameter's DW_AT_GNU_call_site_data_value.
+ /* * DW_TAG_formal_parameter's DW_AT_call_data_value.
It may be NULL if not provided by DWARF. */
const gdb_byte *data_value;
@@ -1120,8 +1119,7 @@ struct call_site_parameter
};
/* * A place where a function gets called from, represented by
- DW_TAG_GNU_call_site. It can be looked up from
- symtab->call_site_htab. */
+ DW_TAG_call_site. It can be looked up from symtab->call_site_htab. */
struct call_site
{
@@ -1135,7 +1133,7 @@ struct call_site
struct call_site *tail_call_next;
- /* * Describe DW_AT_GNU_call_site_target. Missing attribute uses
+ /* * Describe DW_AT_call_target. Missing attribute uses
FIELD_LOC_KIND_DWARF_BLOCK with FIELD_DWARF_BLOCK == NULL. */
struct call_site_target target;
@@ -1149,7 +1147,7 @@ struct call_site
struct dwarf2_per_cu_data *per_cu;
- /* * Describe DW_TAG_GNU_call_site's DW_TAG_formal_parameter. */
+ /* * Describe DW_TAG_call_site's DW_TAG_formal_parameter. */
struct call_site_parameter parameter[1];
};